//! rpt-core: Revealed Preference Theory algorithms in pure Rust.
//!
//! No PyO3 or Python dependency. Can be used standalone from Rust,
//! published to crates.io, or embedded in non-Python systems.

pub mod additive;
pub mod attention;
pub mod ccei;
pub mod closure;
pub mod expenditure;
pub mod gapp;
pub mod garp;
pub mod graph;
pub mod harp;
pub mod houtman_maks;
pub mod intertemporal;
pub mod lp;
pub mod menu;
pub mod mpi;
pub mod production;
pub mod quasilinear;
pub mod scc;
pub mod separability;
pub mod stochastic;
pub mod types;
pub mod utility;
pub mod variants;
pub mod vei;
pub mod welfare;
